@@ -16,6 +16,7 @@
 #include "languagelistmodel.h"
 #include "ui_termedit.h"
 
+#include <kcoreaddons_version.h>
 #include <klocalizedstring.h>
 #include <kmessagebox.h>
 #include <kstandardguiitem.h>
@@ -220,7 +221,7 @@ GlossaryWindow::GlossaryWindow(QWidget *parent)
     m_filterEdit->setClearButtonEnabled(true);
     m_filterEdit->setPlaceholderText(i18n("Quick search..."));
     m_filterEdit->setFocus();
-    m_filterEdit->setToolTip(i18nc("@info:tooltip", "Activated by Ctrl+L.") + ' ' + i18nc("@info:tooltip", "Accepts regular expressions"));
+    m_filterEdit->setToolTip(i18nc("@info:tooltip", "Activated by Ctrl+L. Accepts regular expressions"));
     new QShortcut(Qt::CTRL + Qt::Key_L, this, SLOT(setFocus()), nullptr, Qt::WidgetWithChildrenShortcut);
     connect(m_filterEdit, &QLineEdit::textChanged, m_proxyModel, &GlossaryNS::GlossarySortFilterProxyModel::setFilterRegExp);
 
@@ -228,10 +229,10 @@ GlossaryWindow::GlossaryWindow(QWidget *parent)
     layout->addWidget(m_browser);
     {
         QPushButton* addBtn = new QPushButton(w);
-        connect(addBtn, &QPushButton::clicked, this, QOverload<>::of(&GlossaryWindow::newTermEntry));
+        connect(addBtn, &QPushButton::clicked, this, qOverload<>(&GlossaryWindow::newTermEntry));
 
         QPushButton* rmBtn = new QPushButton(w);
-        connect(rmBtn, &QPushButton::clicked, this, QOverload<>::of(&GlossaryWindow::rmTermEntry));
+        connect(rmBtn, &QPushButton::clicked, this, qOverload<>(&GlossaryWindow::rmTermEntry));
         KGuiItem::assign(addBtn, KStandardGuiItem::add());
         KGuiItem::assign(rmBtn, KStandardGuiItem::remove());
 
@@ -296,10 +297,10 @@ GlossaryWindow::GlossaryWindow(QWidget *parent)
     QStringListModel* subjectFieldsModel = new QStringListModel(this);
     subjectFieldsModel->setStringList(subjectFields);
     m_subjectField->setModel(subjectFieldsModel);
-    connect(m_browser, QOverload<int>::of(&GlossaryTreeView::currentChanged), this, &GlossaryWindow::currentChanged);
-    connect(m_browser, QOverload<const QByteArray &>::of(&GlossaryTreeView::currentChanged), this, &GlossaryWindow::showEntryInEditor);
+    connect(m_browser, qOverload<int>(&GlossaryTreeView::currentChanged), this, &GlossaryWindow::currentChanged);
+    connect(m_browser, qOverload<const QByteArray &>(&GlossaryTreeView::currentChanged), this, &GlossaryWindow::showEntryInEditor);
 
-    connect(m_definitionLang, QOverload<int>::of(&KComboBox::activated), this, &GlossaryWindow::showDefinitionForLang);
+    connect(m_definitionLang, qOverload<int>(&KComboBox::activated), this, &GlossaryWindow::showDefinitionForLang);
     m_definitionLang->setModel(LanguageListModel::emptyLangInstance()->sortModel());
     m_definitionLang->setCurrentIndex(LanguageListModel::emptyLangInstance()->sortModelRowForLangCode(m_defLang));//empty lang
 
@@ -485,6 +486,23 @@ bool GlossaryWindow::queryClose()
     if (glossary->isClean())
         return true;
 
+#if KCOREADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+    switch (KMessageBox::warningTwoActionsCancel(
+                this,
+                i18nc("@info", "The glossary contains unsaved changes.\n"
+                      "Do you want to save your changes or discard them?"),
+                i18nc("@title:window", "Warning"),
+                KStandardGuiItem::save(),
+                KStandardGuiItem::discard())) {
+    case KMessageBox::PrimaryAction:
+        return save();
+    case KMessageBox::SecondaryAction:
+        restore();
+        return true;
+    default:
+        return false;
+    }
+#else
     switch (KMessageBox::warningYesNoCancel(this,
                                             i18nc("@info", "The glossary contains unsaved changes.\n\
 Do you want to save your changes or discard them?"), i18nc("@title:window", "Warning"),
@@ -497,6 +515,7 @@ Do you want to save your changes or discard them?"), i18nc("@title:window", "War
     default:
         return false;
     }
+#endif
 }
 
 
@@ -543,4 +562,4 @@ void TermListView::rmTerms()
         model()->removeRow(row.row());
 }
 
-
+#include "moc_glossarywindow.cpp"
